@@ -1,12 +1,10 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import print_function, division, absolute_import
 
 from .collapse import *
 from .insert import *
 from .split import *
 from .swap import *
 from .weld import *
-from .join import *
+
 
 __all__ = [name for name in dir() if not name.startswith('_')]
