@@ -10,7 +10,7 @@ __all__ = [
 
 
 def is_collapse_legal(mesh, u, v, allow_boundary=False):
-    """Verify if the requested collapse is legal fro a triangle mesh.
+    """Verify if the requested collapse is legal for a triangle mesh.
 
     Parameters
     ----------
@@ -28,37 +28,54 @@ def is_collapse_legal(mesh, u, v, allow_boundary=False):
         `False` otherwise.
 
     """
+    u_on = mesh.is_vertex_on_boundary(u)
+    v_on = mesh.is_vertex_on_boundary(v)
+
+    if v_on and not u_on:
+        return False
+
     # collapsing of boundary vertices is currently not supported
     # change this to `and` to support collapsing to or from the boundary
     if not allow_boundary:
-        if mesh.is_vertex_on_boundary(v) or mesh.is_vertex_on_boundary(u):
+        if u_on or v_on:
             return False
 
+    fkey_uv = mesh.halfedge[u][v]
+    fkey_vu = mesh.halfedge[v][u]
+
     # check for contained faces
     for nbr in mesh.halfedge[u]:
         if nbr in mesh.halfedge[v]:
-            # check if U > V > NBR is a face
-            fkey = mesh.halfedge[u][v]
-            if fkey != mesh.halfedge[v][nbr] or fkey != mesh.halfedge[nbr][u]:
-                # check if V > U > NBR is a face
-                fkey = mesh.halfedge[v][u]
-                if fkey != mesh.halfedge[u][nbr] or fkey != mesh.halfedge[nbr][v]:
-                    return False
+            fkey_nbr_v = mesh.halfedge[nbr][v]
+            fkey_u_nbr = mesh.halfedge[u][nbr]
+
+            if fkey_nbr_v is None and fkey_u_nbr is None:
+                return False
+
+            # in a trimesh
+            # u and v should have one neighbor in common
+            # and uv-nbr or vu-nbr
+            # should define a face
+            # check if UV > NBR is a face
+            if mesh.halfedge[v][nbr] == fkey_uv and mesh.halfedge[nbr][u] != fkey_uv:
+                return False
+            # check if VU > NBR is a face
+            if mesh.halfedge[u][nbr] == fkey_vu and mesh.halfedge[nbr][v] != fkey_vu:
+                return False
 
     for nbr in mesh.halfedge[v]:
         if nbr in mesh.halfedge[u]:
-            # check if U > V > NBR is a face
-            fkey = mesh.halfedge[u][v]
-            if fkey != mesh.halfedge[v][nbr] or fkey != mesh.halfedge[nbr][u]:
-                # check if V > U > NBR is a face
-                fkey = mesh.halfedge[v][u]
-                if fkey != mesh.halfedge[u][nbr] or fkey != mesh.halfedge[nbr][v]:
-                    return False
+            # check if UV > NBR is a face
+            if mesh.halfedge[v][nbr] == fkey_uv and mesh.halfedge[nbr][u] != fkey_uv:
+                return False
+            # check if V > U > NBR is a face
+            if mesh.halfedge[u][nbr] == fkey_vu and mesh.halfedge[nbr][v] != fkey_vu:
+                return False
 
     return True
 
 
-def mesh_collapse_edge(self, u, v, t=0.5, allow_boundary=False, fixed=None):
+def mesh_collapse_edge(mesh, u, v, t=0.5, allow_boundary=False, fixed=None):
     """Collapse an edge to its first or second vertex, or to an intermediate
     point.
 
@@ -92,29 +109,8 @@ def mesh_collapse_edge(self, u, v, t=0.5, allow_boundary=False, fixed=None):
     if t > 1.0:
         raise ValueError('Parameter t should be smaller than or equal to 1.')
 
-    # # collapsing of boundary vertices is currently not supported
-    # # change this to `and` to support collapsing to or from the boundary
-    # if self.is_vertex_on_boundary(u) or self.is_vertex_on_boundary(v):
-    #     return
-
-    # # check for contained faces
-    # for nbr in self.halfedge[u]:
-    #     if nbr in self.halfedge[v]:
-    #         # check if U > V > NBR is a face
-    #         if (self.halfedge[u][v] != self.halfedge[v][nbr] or self.halfedge[u][v] != self.halfedge[nbr][u]):
-    #             # check if V > U > NBR is a face
-    #             if (self.halfedge[v][u] != self.halfedge[u][nbr] or self.halfedge[v][u] != self.halfedge[nbr][v]):
-    #                 return
-    # for nbr in self.halfedge[v]:
-    #     if nbr in self.halfedge[u]:
-    #         # check if U > V > NBR is a face
-    #         if (self.halfedge[u][v] != self.halfedge[v][nbr] or self.halfedge[u][v] != self.halfedge[nbr][u]):
-    #             # check if V > U > NBR is a face
-    #             if (self.halfedge[v][u] != self.halfedge[u][nbr] or self.halfedge[v][u] != self.halfedge[nbr][v]):
-    #                 return
-
     # check collapse conditions
-    if not is_collapse_legal(self, u, v, allow_boundary=allow_boundary):
+    if not is_collapse_legal(mesh, u, v, allow_boundary=allow_boundary):
         return False
 
     # compare to fixed
@@ -123,98 +119,98 @@ def mesh_collapse_edge(self, u, v, t=0.5, allow_boundary=False, fixed=None):
         return False
 
     # move U
-    x, y, z = self.edge_point(u, v, t)
-    self.vertex[u]['x'] = x
-    self.vertex[u]['y'] = y
-    self.vertex[u]['z'] = z
+    x, y, z = mesh.edge_point(u, v, t)
+    mesh.vertex[u]['x'] = x
+    mesh.vertex[u]['y'] = y
+    mesh.vertex[u]['z'] = z
 
     # UV face
-    fkey = self.halfedge[u][v]
+    fkey = mesh.halfedge[u][v]
 
     if fkey is None:
-        del self.halfedge[u][v]
+        del mesh.halfedge[u][v]
 
     else:
-        face = self.face_vertices(fkey)
+        face = mesh.face_vertices(fkey)
         f = len(face)
 
         # switch between UV face sizes
-        # note: in a triself this is not necessary!
+        # note: in a trimesh this is not necessary!
         if f < 3:
-            raise Exception("Invalid self face: {}".format(fkey))
+            raise Exception("Invalid mesh face: {}".format(fkey))
         if f == 3:
             # delete UV
             o = face[face.index(u) - 1]
-            del self.halfedge[u][v]
-            del self.halfedge[v][o]
-            del self.halfedge[o][u]
-            del self.face[fkey]
+            del mesh.halfedge[u][v]
+            del mesh.halfedge[v][o]
+            del mesh.halfedge[o][u]
+            del mesh.face[fkey]
         else:
             # u > v > d => u > d
-            d = self.face_vertex_descendant(fkey, v)
+            d = mesh.face_vertex_descendant(fkey, v)
             face.remove(v)
-            del self.halfedge[u][v]
-            del self.halfedge[v][d]
-            self.halfedge[u][d] = fkey
+            del mesh.halfedge[u][v]
+            del mesh.halfedge[v][d]
+            mesh.halfedge[u][d] = fkey
 
     # VU face
-    fkey = self.halfedge[v][u]
+    fkey = mesh.halfedge[v][u]
 
     if fkey is None:
-        del self.halfedge[v][u]
+        del mesh.halfedge[v][u]
 
     else:
-        face = self.face_vertices(fkey)
+        face = mesh.face_vertices(fkey)
         f = len(face)
 
         # switch between VU face sizes
-        # note: in a triself this is not necessary!
+        # note: in a trimesh this is not necessary!
         if f < 3:
             raise Exception("Invalid mesh face: {}".format(fkey))
         if f == 3:
             # delete UV
             o = face[face.index(v) - 1]
-            del self.halfedge[v][u]  # the collapsing halfedge
-            del self.halfedge[u][o]
-            del self.halfedge[o][v]
-            del self.face[fkey]
+            del mesh.halfedge[v][u]  # the collapsing halfedge
+            del mesh.halfedge[u][o]
+            del mesh.halfedge[o][v]
+            del mesh.face[fkey]
         else:
             # a > v > u => a > u
-            a = self.face_vertex_ancestor(fkey, v)
+            a = mesh.face_vertex_ancestor(fkey, v)
             face.remove(v)
-            del self.halfedge[a][v]
-            del self.halfedge[v][u]
-            self.halfedge[a][u] = fkey
+            del mesh.halfedge[a][v]
+            del mesh.halfedge[v][u]
+            mesh.halfedge[a][u] = fkey
 
     # V neighbors and halfedges coming into V
-    for nbr, fkey in list(self.halfedge[v].items()):
+    for nbr, fkey in list(mesh.halfedge[v].items()):
 
         if fkey is None:
-            self.halfedge[u][nbr] = None
-            del self.halfedge[v][nbr]
+            mesh.halfedge[u][nbr] = None
+            del mesh.halfedge[v][nbr]
         else:
             # a > v > nbr => a > u > nbr
-            face = self.face[fkey]
-            a = self.face_vertex_ancestor(fkey, v)
+            face = mesh.face[fkey]
+            a = mesh.face_vertex_ancestor(fkey, v)
             face[face.index(v)] = u
 
-            if v in self.halfedge[a]:
-                del self.halfedge[a][v]
-            del self.halfedge[v][nbr]
-            self.halfedge[a][u] = fkey
-            self.halfedge[u][nbr] = fkey
+            if v in mesh.halfedge[a]:
+                del mesh.halfedge[a][v]
+            del mesh.halfedge[v][nbr]
+            mesh.halfedge[a][u] = fkey
+            mesh.halfedge[u][nbr] = fkey
 
         # only update what will not be updated in the previous part
         # verify what this is exactly
         # nbr > v > d => nbr > u > d
-        if v in self.halfedge[nbr]:
-            fkey = self.halfedge[nbr][v]
-            del self.halfedge[nbr][v]
-            self.halfedge[nbr][u] = fkey
+        if v in mesh.halfedge[nbr]:
+            fkey = mesh.halfedge[nbr][v]
+            del mesh.halfedge[nbr][v]
+            mesh.halfedge[nbr][u] = fkey
 
     # delete V
-    del self.halfedge[v]
-    del self.vertex[v]
+    del mesh.halfedge[v]
+    del mesh.vertex[v]
 
 
 # split this up into more efficient cases
@@ -224,7 +220,7 @@ def mesh_collapse_edge(self, u, v, t=0.5, allow_boundary=False, fixed=None):
 # - u and v on boundary
 
 
-def trimesh_collapse_edge(self, u, v, t=0.5, allow_boundary=False, fixed=None):
+def trimesh_collapse_edge(mesh, u, v, t=0.5, allow_boundary=False, fixed=None):
     """Collapse an edge to its first or second vertex, or to an intermediate
     point.
 
@@ -286,8 +282,9 @@ def trimesh_collapse_edge(self, u, v, t=0.5, allow_boundary=False, fixed=None):
         import compas
 
         from compas.datastructures import Mesh
+        from compas.datastructures import mesh_quads_to_triangles
+        from compas.datastructures import trimesh_collapse_edge
         from compas.plotters import MeshPlotter
-        from compas.topology import mesh_quads_to_triangles
 
         mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -295,7 +292,7 @@ def trimesh_collapse_edge(self, u, v, t=0.5, allow_boundary=False, fixed=None):
 
         u, v = mesh.get_any_edge()
 
-        mesh.collapse_edge_tri(u, v)
+        trimesh_collapse_edge(mesh, u, v)
 
         plotter = MeshPlotter(mesh)
 
@@ -311,96 +308,99 @@ def trimesh_collapse_edge(self, u, v, t=0.5, allow_boundary=False, fixed=None):
         raise ValueError('Parameter t should be smaller than or equal to 1.')
 
     # check collapse conditions
-    if not is_collapse_legal(self, u, v, allow_boundary=allow_boundary):
+    if not is_collapse_legal(mesh, u, v, allow_boundary=allow_boundary):
         return False
 
+    if mesh.is_vertex_on_boundary(u):
+        t = 0.0
+
     # compare to fixed
     fixed = fixed or []
     if v in fixed or u in fixed:
         return False
 
     # move U
-    x, y, z = self.edge_point(u, v, t)
+    x, y, z = mesh.edge_point(u, v, t)
 
-    self.vertex[u]['x'] = x
-    self.vertex[u]['y'] = y
-    self.vertex[u]['z'] = z
+    mesh.vertex[u]['x'] = x
+    mesh.vertex[u]['y'] = y
+    mesh.vertex[u]['z'] = z
 
     # UV face
-    fkey = self.halfedge[u][v]
+    fkey = mesh.halfedge[u][v]
 
     if fkey is None:
-        del self.halfedge[u][v]
+        del mesh.halfedge[u][v]
     else:
-        face = self.face[fkey]
+        face = mesh.face[fkey]
 
         o = face[face.index(u) - 1]
 
-        del self.halfedge[u][v]
-        del self.halfedge[v][o]
-        del self.halfedge[o][u]
-        del self.face[fkey]
+        del mesh.halfedge[u][v]
+        del mesh.halfedge[v][o]
+        del mesh.halfedge[o][u]
+        del mesh.face[fkey]
 
-        if len(self.halfedge[o]) < 2:
-            del self.halfedge[o]
-            del self.vertex[o]
-            del self.halfedge[u][o]
+        if len(mesh.halfedge[o]) < 2:
+            del mesh.halfedge[o]
+            del mesh.vertex[o]
+            del mesh.halfedge[u][o]
 
     # VU face
-    fkey = self.halfedge[v][u]
+    fkey = mesh.halfedge[v][u]
 
     if fkey is None:
-        del self.halfedge[v][u]
+        del mesh.halfedge[v][u]
     else:
-        face = self.face[fkey]
+        face = mesh.face[fkey]
 
         o = face[face.index(v) - 1]
 
-        del self.halfedge[v][u]
-        del self.halfedge[u][o]
-        del self.halfedge[o][v]
-        del self.face[fkey]
+        del mesh.halfedge[v][u]
+        del mesh.halfedge[u][o]
+        del mesh.halfedge[o][v]
+        del mesh.face[fkey]
 
-        if len(self.halfedge[o]) < 2:
-            del self.halfedge[o]
-            del self.vertex[o]
-            del self.halfedge[v][o]
+        if len(mesh.halfedge[o]) < 2:
+            del mesh.halfedge[o]
+            del mesh.vertex[o]
+            del mesh.halfedge[v][o]
 
     # neighborhood of V
-    for nbr, fkey in list(self.halfedge[v].items()):
+    for nbr, fkey in list(mesh.halfedge[v].items()):
 
         if fkey is None:
-            self.halfedge[u][nbr] = None
-            del self.halfedge[v][nbr]
+            mesh.halfedge[u][nbr] = None
+            del mesh.halfedge[v][nbr]
         else:
             # a > v > nbr => a > u > nbr
-            face = self.face[fkey]
+            face = mesh.face[fkey]
             a = face[face.index(v) - 1]
-            self.face[fkey] = [a, u, nbr]
+            mesh.face[fkey] = [a, u, nbr]
 
-            if v in self.halfedge[a]:
-                del self.halfedge[a][v]
-            del self.halfedge[v][nbr]
+            if v in mesh.halfedge[a]:
+                del mesh.halfedge[a][v]
+            del mesh.halfedge[v][nbr]
 
-            self.halfedge[a][u] = fkey
-            self.halfedge[u][nbr] = fkey
-            self.halfedge[nbr][a] = fkey
+            mesh.halfedge[a][u] = fkey
+            mesh.halfedge[u][nbr] = fkey
+            mesh.halfedge[nbr][a] = fkey
 
         # nbr > v > d => nbr > u > d
-        if v in self.halfedge[nbr]:
-            self.halfedge[nbr][u] = self.halfedge[nbr][v]
-            del self.halfedge[nbr][v]
+        if v in mesh.halfedge[nbr]:
+            mesh.halfedge[nbr][u] = mesh.halfedge[nbr][v]
+            del mesh.halfedge[nbr][v]
 
     # delete V
-    del self.halfedge[v]
-    del self.vertex[v]
+    del mesh.halfedge[v]
+    del mesh.vertex[v]
 
     # clean up
-    for nu in self.halfedge[u]:
-        for nbr in self.halfedge[nu]:
+    for nu in mesh.halfedge[u]:
+        for nbr in mesh.halfedge[nu]:
             if nbr == v:
-                self.halfedge[nu][u] = self.halfedge[nu][v]
-                del self.halfedge[nu][v]
+                mesh.halfedge[nu][u] = mesh.halfedge[nu][v]
+                del mesh.halfedge[nu][v]
 
     return True
 
@@ -414,17 +414,17 @@ if __name__ == "__main__":
     import compas
 
     from compas.datastructures import Mesh
+    from compas.datastructures import mesh_quads_to_triangles
+    from compas.datastructures import trimesh_collapse_edge
     from compas.plotters import MeshPlotter
-    from compas.topology import mesh_quads_to_triangles
 
     mesh = Mesh.from_obj(compas.get('faces.obj'))
 
     mesh_quads_to_triangles(mesh)
 
-    mesh.swap_edge_tri(14, 19)
-    mesh.swap_edge_tri(21, 16)
-
-    mesh.collapse_edge_tri(21, 15)
+    trimesh_collapse_edge(mesh, 21, 27)
+    trimesh_collapse_edge(mesh, 0, 6, allow_boundary=True)
+    trimesh_collapse_edge(mesh, 1, 7, allow_boundary=True)
 
     plotter = MeshPlotter(mesh, figsize=(10, 7))
 
