@@ -64,6 +64,15 @@ decorators
 
     memoize
 
+functions
+==========
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    fibonacci
+    binomial_coefficient
 
 itertools
 =========
@@ -140,6 +149,18 @@ profiling
     print_profile
 
 
+statistics
+==========
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    average
+    variance
+    standard_deviation
+
+
 xfunc
 =====
 
@@ -182,5 +203,6 @@ from .sorting import *
 from .xfunc import *
 from .xscript import *
 from .functions import *
+from .statistics import *
 
 __all__ = [name for name in dir() if not name.startswith('_')]
