@@ -10,13 +10,7 @@ else:
     from PySide2 import QtCore
 
 
-__author__    = ['Tom Van Mele', ]
-__copyright__ = 'Copyright 2016 - Block Research Group, ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'vanmelet@ethz.ch'
-
-
-__all__ = ['Mouse', ]
+__all__ = ['Mouse']
 
 
 class Mouse(object):
