@@ -2,8 +2,6 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-import time
-
 import compas
 import compas_rhino
 
@@ -41,7 +39,7 @@ class MeshArtist(FaceArtist, EdgeArtist, VertexArtist, Artist):
     Examples
     --------
     .. code-block:: python
-        
+
         import compas
         from compas.datastructures import Mesh
         from compas_rhino.artists import MeshArtist
@@ -77,7 +75,7 @@ class MeshArtist(FaceArtist, EdgeArtist, VertexArtist, Artist):
     def mesh(self, mesh):
         self.datastructure = mesh
 
-    def draw(self):
+    def draw_mesh(self):
         """Draw the mesh as a consolidated RhinoMesh.
 
         Notes
@@ -100,6 +98,9 @@ class MeshArtist(FaceArtist, EdgeArtist, VertexArtist, Artist):
         name = "{}.mesh".format(self.mesh.name)
         return compas_rhino.xdraw_mesh(vertices, new_faces, layer=layer, name=name)
 
+    def clear_mesh(self):
+        compas_rhino.delete_objects(compas_rhino.get_objects(name="{}.mesh".format(self.mesh.name)))
+
     def clear(self):
         """Clear the vertices, faces and edges of the mesh, without clearing the
         other elements in the layer.
@@ -107,6 +108,7 @@ class MeshArtist(FaceArtist, EdgeArtist, VertexArtist, Artist):
         """
         self.clear_vertices()
         self.clear_faces()
+        self.clear_mesh()
         self.clear_edges()
 
 
@@ -115,13 +117,13 @@ class MeshArtist(FaceArtist, EdgeArtist, VertexArtist, Artist):
 # ==============================================================================
 
 if __name__ == "__main__":
-    
+
     import os
 
     from compas.datastructures import Mesh
     from compas.geometry import Polyhedron
 
-    from compas_rhino.artists.meshartist import MeshArtist
+    from compas_rhino.artists import MeshArtist
 
     poly = Polyhedron.generate(12)
 
